package net.h34t.filemure

import io.javalin.Javalin
import net.h34t.filemure.controller.LimboController
import net.h34t.filemure.controller.LoginController
import net.h34t.filemure.controller.OverviewController
import net.h34t.filemure.controller.UploadController
import net.h34t.filemure.repository.SqliteRepository

class FilemureApp(repository: SqliteRepository) {

    private val modifiers = TemplateModifiers()

    private val loginPageController = LoginController(modifiers, repository)

    private val overviewController = OverviewController(modifiers, repository)
    private val limboController = LimboController(modifiers, repository)
    private val uploadController = UploadController(modifiers, repository)

    fun register(server: Javalin) {
        server.get("/") { ctx ->
            if (ctx.getSession() != null) {
                overviewController.overview(ctx)
            } else {
                ctx.redirectPRG("/login")
            }
        }
        server.get("/login", loginPageController::formLogin)
        server.post("/login", loginPageController::doLogin)
        server.post("/logout", loginPageController::doLogout)

        server.post("/upload", uploadController::upload)
        server.get("/limbo", limboController::formLimbo)
    }
}